@@ -5,6 +5,7 @@ A module containing the Tiddler class and related functions.
 import re
 
 from datetime import datetime
+from time import strptime
 
 
 def current_timestring():
@@ -15,6 +16,22 @@ def current_timestring():
     return unicode(time_object.strftime('%Y%m%d%H%M%S'))
 
 
+def timestring_to_datetime(timestring):
+    """
+    Turn a tiddler timestring into a datetime object.
+
+    Will raise ValueError if the input is not a 12 or 14
+    digit timestring.
+    """
+    try:
+        timestring_datetime = datetime(*(strptime(timestring,
+            '%Y%m%d%H%M')[0:6]))
+    except ValueError:
+        timestring_datetime = datetime(*(strptime(timestring,
+            '%Y%m%d%H%M%S')[0:6]))
+    return timestring_datetime
+
+
 def tags_list_to_string(tags):
     """
     Given a list of tags, turn them into the canonical string representation
